@@ -563,22 +563,19 @@ void CSSFontSelector::addFontFaceRule(const CSSFontFaceRuleImpl *fontFaceRule)
             source = new CSSFontFaceSource(item->resource());
         }
 
-        if (!fontFace) {
-            fontFace = new CSSFontFace(static_cast<FontTraitsMask>(traitsMask), this);
-        }
-
         if (source) {
 #if 0
             // ENABLE(SVG_FONTS)
             source->setSVGFontFaceElement(item->svgFontFaceElement());
 #endif
+            if (!fontFace) {
+                fontFace = new CSSFontFace(static_cast<FontTraitsMask>(traitsMask), this);
+            }
             fontFace->addSource(source);
         }
     }
 
-    assert(fontFace);
-
-    if (fontFace && !fontFace->isValid()) {
+    if (!fontFace || !fontFace->isValid()) {
         delete fontFace;
         return;
     }
@@ -669,6 +666,11 @@ void CSSFontSelector::addFontFaceRule(const CSSFontFaceRuleImpl *fontFaceRule)
                 familyFontFaces->append(fontFace);
         */
     }
+
+    // Should be impossible, but in case empty/invalid family name makes it through...
+    if (fontFace->refCount() < 1) {
+        delete fontFace;
+    }
 }
 
 void CSSFontSelector::requestFamilyName(const DOMString &familyName)
